==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/pt_BR.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Suas configurações foram atualizadas.",
"Activity" => "Atividade",
"A file or folder has been <strong>shared</strong>" => "Um arquivo ou pasta foi <strong>compartilhado</strong> ",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Um novo arquivo ou pasta foi <strong>criado</strong> em uma pasta compartilhada",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Um arquivo ou pasta foi <strong>alterado</strong> em uma pasta compartilhada",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Um novo arquivo ou pasta foi <strong>apagada</strong> de uma pasta compartilhada",
"You created %1\$s" => "Você criou %1\$s",
"%2\$s created %1\$s" => "%2\$s criou %1\$s",
"You changed %1\$s" => "Você modificou %1\$s",
"%2\$s changed %1\$s" => "%2\$s modificou %1\$s",
"You deleted %1\$s" => "Você eliminou %1\$s ",
"%2\$s deleted %1\$s" => "%2\$s eliminou %1\$s",
"You shared %1\$s with %2\$s" => "Você compartilhou %1\$s com %2\$s",
"You shared %1\$s with group %2\$s" => "Você compartilhou %1\$s com o grupo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s compartilhou %1\$s com você",
"You shared %1\$s via link" => "Você compartilhou %1\$s via link",
"Activity notification" => "Notificação de atividade",
"All Activities" => "Todas as Atividades",
"Activities by you" => "Atividades por você",
"Activities by others" => "Atividades por outros",
"Shares" => "Compartilhamentos",
"Files" => "Arquivos",
"%s and %s" => "%s e %s",
", " => ",",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s e <strong class=\"tooltip\" title=\"%s\">mais %n</strong>","%s e <strong class=\"tooltip\" title=\"%s\">mais %n</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s e mais %n","%s e mais %n"),
"Hello %s," => "Olá %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Você está recebendo este e-mail porque na última hora as seguintes coisas aconteceram em %s",
"You are receiving this email because in the last day the following things happened at %s" => "Você está recebendo este e-mail porque no último dia as seguintes coisas aconteceram em %s",
"You are receiving this email because in the last week the following things happened at %s" => "Você está recebendo este e-mail porque na última semana as seguintes coisas aconteceram em %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Você verá uma lista de eventos aqui quando começar a usar o seu %s.",
"No more events to load" => "Não ha mais eventos para carregar",
"Enable RSS feed" => "Habilitar alimentação RRS",
"Notifications" => "Notificações",
"Mail" => "EMail",
"Stream" => "Fluxo",
"You need to set up your email address before you can receive notification emails." => "Você precisa configurar o endereço de e-mail antes que você possa receber e-mails de notificação.",
"Send emails:" => "Enviar e-mails:",
"Hourly" => "De hora em hora",
"Daily" => "Diário",
"Weekly" => "Semanal",
"Activity feed" => "Alimentação de atividade",
"Personal activity feed for %s" => "Alimentação de atividade pessoal para %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/pt_BR.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Suas configurações foram atualizadas.",
"Activity" => "Atividade",
"A file or folder has been <strong>shared</strong>" => "Um arquivo ou pasta foi <strong>compartilhado</strong> ",
"A new file or folder has been <strong>created</strong>" => "Um novo arquivo ou pasta foi <strong>criado</strong>",
"A file or folder has been <strong>changed</strong>" => "Um arquivo ou pasta foi <strong>modificado</strong>",
"A file or folder has been <strong>deleted</strong>" => "Um arquivo ou pasta foi <strong>excluído</strong>",
"You created %1\$s" => "Você criou %1\$s",
"%2\$s created %1\$s" => "%2\$s criou %1\$s",
"You changed %1\$s" => "Você modificou %1\$s",
"%2\$s changed %1\$s" => "%2\$s modificou %1\$s",
"You deleted %1\$s" => "Você eliminou %1\$s ",
"%2\$s deleted %1\$s" => "%2\$s eliminou %1\$s",
"You shared %1\$s with %2\$s" => "Você compartilhou %1\$s com %2\$s",
"You shared %1\$s with group %2\$s" => "Você compartilhou %1\$s com o grupo %2\$s",
"%2\$s shared %1\$s with you" => "%2\$s compartilhou %1\$s com você",
"You shared %1\$s via link" => "Você compartilhou %1\$s via link",
"Activity notification" => "Notificação de atividade",
"All Activities" => "Todas as Atividades",
"Activities by you" => "Atividades por você",
"Activities by others" => "Atividades por outros",
"Shares" => "Compartilhamentos",
"Files" => "Arquivos",
"%s and %s" => "%s e %s",
", " => ",",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s e <strong class=\"tooltip\" title=\"%s\">mais %n</strong>","%s e <strong class=\"tooltip\" title=\"%s\">mais %n</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s e mais %n","%s e mais %n"),
"Hello %s," => "Olá %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Você está recebendo este e-mail porque na última hora as seguintes coisas aconteceram em %s",
"You are receiving this email because in the last day the following things happened at %s" => "Você está recebendo este e-mail porque no último dia as seguintes coisas aconteceram em %s",
"You are receiving this email because in the last week the following things happened at %s" => "Você está recebendo este e-mail porque na última semana as seguintes coisas aconteceram em %s",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Você verá uma lista de eventos aqui quando começar a usar o seu %s.",
"No more events to load" => "Não ha mais eventos para carregar",
"Enable RSS feed" => "Habilitar alimentação RRS",
"Notifications" => "Notificações",
"Mail" => "EMail",
"Stream" => "Fluxo",
"Notify about my own actions" => "Notifique sobre minhas próprias ações",
"You need to set up your email address before you can receive notification emails." => "Você precisa configurar o endereço de e-mail antes que você possa receber e-mails de notificação.",
"Send emails:" => "Enviar e-mails:",
"Hourly" => "De hora em hora",
"Daily" => "Diário",
"Weekly" => "Semanal",
"Activity feed" => "Alimentação de atividade",
"Personal activity feed for %s" => "Alimentação de atividade pessoal para %s"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
